==> flipnslide-0.0.0.tar.gz: flipnslide-0.0.0/README.md <==
# Flip-n-Slide

Flip-n-Slide is a concise tiling and augmentation strategy to prepare large scientific images for use with GPU-enabled algorithms. `flipnslide` is a Python package that outputs PyTorch ready preprocessed datasets from a single large image.

## Documentation

The documentation for `flipnside` is under construction, and will be hosted on [Read the Docs]().

## Installation and Dependencies

For now, `flipnside` can be implemented locally by cloning this repository.

```bash
git clone https://github.com/elliesch/flipnslide.git
```
Check back next week for instructions on installing this from PyPI and Conda Forge.

## Attribution

If you make use of this code, please cite the ICLR paper:

    @inproceedings{flipnslide,
      author       = {Ellianna Abrahams and
                      Tasha Snow and
                      Matthew R. Siegfried and
                      Fernando Pérez},
      title        = {A Concise Tiling Strategy for Preserving Spatial Context in Earth Observation Imagery},
      booktitle    = {Machine Learning for Remote Sensing Workshop {ML4RS} at The Twelfth International Conference 
                      on Learning Representations, {ICLR} 2024, Vienna, Austria, May 7-11, 2024},
      publisher    = {OpenReview.net},
      year         = {2024},
      url          = {upcoming},
    }

## License

Copyright 2024 Ellianna Abrahams, Tasha Snow, Matthew R. Siegfried, Fernando Pérez, and contributors.

``flipnslide`` is free software made available under the MIT License. For details see
the [LICENSE](https://github.com/elliesch/flipnslide/blob/main/LICENSE) file.

## Contributors

See the [AUTHORS](https://github.com/elliesch/flipnslide/blob/main/AUTHORS) file for a complete list of contributors to the project.

==> flipnslide-0.0.1.tar.gz: flipnslide-0.0.1/README.md <==
# Flip-n-Slide

Flip-n-Slide is a concise tiling and augmentation strategy to prepare large scientific images for use with GPU-enabled algorithms. `flipnslide` is a Python package that outputs PyTorch ready preprocessed datasets from a single large image.

## Documentation

The documentation for `flipnside` is available on [Read the Docs](https://flipnslide.readthedocs.io/).

## Installation and Dependencies

For now, `flipnslide` can be installed from PyPI using pip, by running:

```bash
pip install flipnslide
```
Check back later this week for instructions on installing from conda forge.

## Attribution

If you make use of this code, please cite the companion ML4RS @ ICLR paper:

    @inproceedings{flipnslide,
      author       = {Ellianna Abrahams and
                      Tasha Snow and
                      Matthew R. Siegfried and
                      Fernando Pérez},
      title        = {A Concise Tiling Strategy for Preserving Spatial Context in Earth Observation Imagery},
      booktitle    = {Machine Learning for Remote Sensing Workshop {ML4RS} at The Twelfth International Conference 
                      on Learning Representations, {ICLR} 2024, Vienna, Austria, May 7-11, 2024},
      publisher    = {OpenReview.net},
      year         = {2024},
      url          = {upcoming},
    }

## License

Copyright 2024 Ellianna Abrahams, Tasha Snow, Matthew R. Siegfried, Fernando Pérez, and contributors.

``flipnslide`` is free software made available under the MIT License. For details see
the [LICENSE](https://github.com/elliesch/flipnslide/blob/main/LICENSE) file.

## Contributors

See the [AUTHORS](https://github.com/elliesch/flipnslide/blob/main/AUTHORS) file for a complete list of contributors to the project.
